@@ -1,10 +1,10 @@
 ;;; LaHaShem HaAretz U'Mloah
 
-;;; Stalin 0.9 - A global optimizing compiler for Scheme
+;;; Stalin 0.10 - A global optimizing compiler for Scheme
 ;;; Copyright 1993, 1994, and 1995 University of Toronto. All rights reserved.
 ;;; Copyright 1996 Technion. All rights reserved.
 ;;; Copyright 1996 and 1997 University of Vermont. All rights reserved.
-;;; Copyright 1997, 1998, 1999, and 2000 NEC Research Institute, Inc. All
+;;; Copyright 1997, 1998, 1999, 2000, and 2001 NEC Research Institute, Inc. All
 ;;; rights reserved.
 
 ;;; This program is free software; you can redistribute it and/or
@@ -566,8 +566,9 @@
  (stalin:externalize-type-set-internal w '()))
 
 (defun stalin:show-type-set (w)
- (lisp-display-output
-  (with-output-to-string (pp (stalin:externalize-type-set w)))))
+ (ilisp-display-output-adaptively
+  (with-output-to-string (pp (stalin:externalize-type-set w)))
+  ilisp-arglist-output))
 
 (defun stalin:goto-variable (g)
  (let ((p (stalin:variable-character-position g)))
